@@ -212,7 +212,7 @@ socket_read_incoming (LmOldSocket *socket,
                                           NULL);
     }
 
-    if (status != G_IO_STATUS_NORMAL || *bytes_read < 0) {
+    if (status != G_IO_STATUS_NORMAL) {
         switch (status) {
         case G_IO_STATUS_EOF:
             *reason = LM_DISCONNECT_REASON_HUP;
@@ -953,7 +953,7 @@ lm_old_socket_close (LmOldSocket *socket)
     data = socket->connect_data;
     if (data) {
         if (data->io_channel) {
-	    socket_close_io_channel (data->io_channel);
+            socket_close_io_channel (data->io_channel);
         }
         socket->connect_data = NULL;
         g_free (data);
